@@ -35,10 +35,6 @@
 
 #include <linux/seq_file.h>
 
-#ifndef OLD_KERNEL
-#include <linux/statfs.h>
-#endif
-
 extern struct seq_operations cdfs_operations;
 extern struct _track_info *dummy_track_p;
 
@@ -93,11 +89,11 @@ cdfs_release(struct inode *inode_p, struct file *file_p) {
  ******************************************************************************/
 
 struct file_operations proc_cdfs_operations = {
-    .owner	= THIS_MODULE,
-    .llseek	= seq_lseek,
-    .read	= seq_read,
-    .open	= cdfs_open,
-    .release	= cdfs_release,
+    owner:	THIS_MODULE,
+    llseek:	seq_lseek,
+    read:	seq_read,
+    open:	cdfs_open,
+    release:	cdfs_release,
 };
 
 
@@ -113,39 +109,26 @@ extern cd * cdfs_proc_cd;
 
 /********************************************************************/
 
-#ifdef OLD_KERNEL
 static struct super_block * cdfs_mount(struct super_block *sb, void *data, int silent){
   kdev_t dev = sb->s_dev;
   int i, j, t;
   struct cdrom_tochdr  hdr;
-#else
-static int cdfs_fill_super(struct super_block *sb, void *data, int silent){
-  int i, t;
-#endif
   struct cdrom_tocentry   entry;   
   int no_audio=0, no_data=0;
   cd * this_cd;
 
   PRINT("cdfs_mount\n");
 
-#ifdef OLD_KERNEL
   MOD_INC_USE_COUNT;
 
   set_blocksize(dev, CD_FRAMESIZE);  // voor bread met ide-cd
-#else
-  sb_set_blocksize(sb, CD_FRAMESIZE);  // voor bread met ide-cd
-#endif
 
   sb->s_blocksize = CD_FRAMESIZE;
   sb->s_blocksize_bits = 11;
 
   if (!(this_cd = cdfs_info(sb) = kmalloc(sizeof(cd), GFP_KERNEL))){
-#ifdef OLD_KERNEL
     MOD_DEC_USE_COUNT;     
     return NULL;
-#else
-    return -ENOMEM;
-#endif
   }
 
   this_cd->mode           = MODE;
@@ -157,13 +140,8 @@ static int cdfs_fill_super(struct super_block *sb, void *data, int silent){
 
   // Initialize cache for maximum sector size
   if (!(this_cd->cache = kmalloc(CD_FRAMESIZE_RAWER*CACHE_SIZE, GFP_KERNEL))) {
-#ifdef OLD_KERNEL
     MOD_DEC_USE_COUNT;
     return NULL;
-#else
-    kfree(cdfs_info(sb));
-    return -ENOMEM;
-#endif
   }
 
   // Cache is still invalid
@@ -180,23 +158,15 @@ static int cdfs_fill_super(struct super_block *sb, void *data, int silent){
   if (this_cd->toc_scsi){
     if (cdfs_toc_read_full(sb)){
       printk("TOC read failed\n");
-#ifdef OLD_KERNEL
       MOD_DEC_USE_COUNT;
       return NULL;
-#else
-      goto invalid;
-#endif
     }
   } else {
     //if (cdfs_ioctl(sb, CDROMREADTOCHDR, (unsigned long)&hdr)){
     if (cdfs_toc_read(sb)){
       printk("cdfs_toc_read failed\n");
-#ifdef OLD_KERNEL
       MOD_DEC_USE_COUNT;
       return NULL;
-#else
-      goto invalid;
-#endif
     }
   }
 
@@ -259,7 +229,7 @@ static int cdfs_fill_super(struct super_block *sb, void *data, int silent){
 	no_audio++;
 	this_cd->track[i].iso_info    = NULL;
 	this_cd->track[i].type        = AUDIO;
-	this_cd->track[i].time        = get_seconds();
+	this_cd->track[i].time        = CURRENT_TIME;
 	this_cd->track[i].iso_size    = 0;
 	this_cd->track[i].track_size  = this_cd->track[i].track_size * CD_FRAMESIZE_RAW + ((this_cd->raw_audio==0)?WAV_HEADER_SIZE:0);
 	this_cd->track[i].size        = this_cd->track[i].track_size;
@@ -361,16 +331,7 @@ out:;
   
   cdfs_proc_cd = this_cd;
 
-#ifdef OLD_KERNEL
   return sb;
-#else
-  return 0;
-
-invalid:
-  kfree(this_cd->cache);
-  kfree(cdfs_info(sb));
-  return -EINVAL;
-#endif
 }
 
 /************************************************************************/
@@ -393,19 +354,13 @@ static void cdfs_umount(struct super_block *sb) {
   cdfs_proc_cd = NULL; 
   kfree(cdfs_info(sb));
 
-#ifdef OLD_KERNEL
   MOD_DEC_USE_COUNT;
-#endif
 
 }
 
 /************************************************************************/
 
-#ifdef OLD_KERNEL
 static int cdfs_statfs(struct super_block *sb, struct statfs *buf) {
-#else
-static int cdfs_statfs(struct super_block *sb, struct kstatfs *buf) {
-#endif
   cd * this_cd = cdfs_info(sb);
   PRINT("rmfs_statfs\n");
 
@@ -436,11 +391,7 @@ static int cdfs_readdir(struct file *filp, void *dirent, filldir_t filldir) {
 
 /************************************************************************/
 
-#ifdef OLD_KERNEL
 static struct dentry * cdfs_lookup(struct inode *dir, struct dentry *dentry){
-#else
-static struct dentry * cdfs_lookup(struct inode *dir, struct dentry *dentry, struct nameidata *nd){
-#endif
   struct inode * inode;
   int i;
   cd * this_cd = cdfs_info(dir->i_sb);
@@ -463,12 +414,12 @@ static struct dentry * cdfs_lookup(struct inode *dir, struct dentry *dentry, str
 /***************************************************************************/
 
 static struct file_operations cdfs_dir_operations = {
-  .read     = generic_read_dir,
-  .readdir  = cdfs_readdir,
+  read:       generic_read_dir,
+  readdir:    cdfs_readdir,
 };
 
 static struct inode_operations cdfs_inode_operations = {
-  .lookup   = cdfs_lookup
+  lookup:     cdfs_lookup
 };
 
 /**************************************************************************/
@@ -483,7 +434,7 @@ static void cdfs_read_inode(struct inode *i) {
   i->i_uid        = this_cd->uid;
   i->i_gid        = this_cd->gid;
   i->i_nlink      = 1;
-  i->i_op         = &cdfs_inode_operations;
+  i->i_op         = NULL;
   i->i_fop        = NULL;
   i->i_data.a_ops = NULL;
 
@@ -491,15 +442,11 @@ static void cdfs_read_inode(struct inode *i) {
     i->i_size  = 0;                      /* Uuugh ?? */
     i->i_mtime = i->i_atime = i->i_ctime = CURRENT_TIME;
     i->i_mode  = S_IFDIR | S_IRUSR | S_IXUSR | S_IRGRP |  S_IXGRP | S_IROTH | S_IXOTH;
+    i->i_op    = &cdfs_inode_operations;
     i->i_fop   = &cdfs_dir_operations;
   } else {                                          /* file */
     i->i_size  = this_cd->track[i->i_ino].size;
-#ifdef OLD_KERNEL
     i->i_mtime = i->i_atime = i->i_ctime = this_cd->track[i->i_ino].time;
-#else
-    i->i_mtime.tv_sec = i->i_atime.tv_sec = i->i_ctime.tv_sec = this_cd->track[i->i_ino].time;
-    i->i_mtime.tv_nsec = i->i_atime.tv_nsec = i->i_ctime.tv_nsec = 0;
-#endif
     i->i_mode  = this_cd->mode;
     if ((this_cd->track[i->i_ino].type==DATA) && this_cd->track[i->i_ino].iso_size) {
       i->i_fop          = &cdfs_cddata_file_operations; 
@@ -531,36 +478,20 @@ static void cdfs_read_inode(struct inode *i) {
 /******************************************************************/
 
 static struct super_operations cdfs_ops = {
-  .read_inode = cdfs_read_inode,
-  .put_super  = cdfs_umount,
-  .statfs     = cdfs_statfs
+  read_inode: cdfs_read_inode,
+  put_super:  cdfs_umount,
+  statfs:     cdfs_statfs
 };
 
-#ifdef OLD_KERNEL
 static DECLARE_FSTYPE_DEV(cdfs_fs_type, FSNAME, cdfs_mount);
-#else
-static struct super_block *cdfs_get_sb(struct file_system_type *fs_type, int flags, const char *dev_name, void *data) {
-  return get_sb_bdev(fs_type, flags, dev_name, data, cdfs_fill_super);
-}
-
-static struct file_system_type cdfs_fs_type = {
-  .owner    = THIS_MODULE,
-  .name     = "cdfs",
-  .get_sb   = cdfs_get_sb,
-  .kill_sb  = kill_block_super,
-  .fs_flags = FS_REQUIRES_DEV
-};
-#endif
 
 /******************************************************/
 
-MODULE_AUTHOR("Michiel Ronsse (ronsse@elis.UGent.be)");
+MODULE_AUTHOR("Michiel Ronsse (ronsse@elis.rug.ac.be)");
 MODULE_DESCRIPTION("CDfs: a CD filesystem");
 MODULE_LICENSE("GPL"); 
 
-#ifdef OLD_KERNEL
 EXPORT_NO_SYMBOLS;
-#endif
 
 /******************************************************************/
 
@@ -613,11 +544,7 @@ void cdfs_parse_options(char *options, cd * this_cd) {
   
   if (!options) return;
   
-#ifdef OLD_KERNEL
   for (this_char = strtok(options,","); this_char; this_char = strtok(NULL,",")) {
-#else
-  while ((this_char = strsep(&options,",")) != NULL) {
-#endif
     
     if (!strcmp(this_char,"single")) 
       this_cd->single=TRUE;
